@@ -3,9 +3,6 @@
 define('ADMINER_DIR', '/usr/share/adminer');
 
 function adminer_object() {
-    // required to run any plugin
-    include_once ADMINER_DIR . "/include/plugins.inc.php";
-
     // autoloader
     foreach (glob(ADMINER_DIR . "/plugins/*.php") as $filename) {
         include_once $filename;
